@@ -1,8 +1,8 @@
-from django.conf.urls import include, patterns, url
+from django.conf.urls import include, url
 
 
-urlpatterns = patterns(
-    '',
+app_name = 'user_management_api_avatar'
+urlpatterns = [
     url(r'', include('user_management.api.avatar.urls.profile_avatar')),
     url(r'', include('user_management.api.avatar.urls.user_avatar')),
-)
+]
