@@ -1,13 +1,12 @@
-from django.conf.urls import patterns, url
+from django.conf.urls import url
 
 from .. import views
 
 
-urlpatterns = patterns(
-    '',
+urlpatterns = [
     url(
         regex=r'^users/(?P<pk>\d+)/avatar/?$',
         view=views.UserAvatar.as_view(),
         name='user_avatar',
     ),
-)
+]
