@@ -1,6 +1,5 @@
-import datetime
-
 from django.core.management.base import BaseCommand
+from django.utils import timezone
 
 from user_management.api.models import AuthToken
 
@@ -9,6 +8,5 @@ class Command(BaseCommand):
     help = "Remove expired auth tokens from the database."
 
     def handle(self, *args, **options):
-        now = datetime.datetime.now()
-
+        now = timezone.now()
         AuthToken.objects.filter(expires__lte=now).delete()
