@@ -4,7 +4,7 @@ from rest_framework.permissions import BasePermission, SAFE_METHODS
 class IsNotAuthenticated(BasePermission):
     """Permit only users that are NOT logged in!"""
     def has_permission(self, request, view):
-        return request.user.is_anonymous()
+        return request.user.is_anonymous
 
 
 class IsAdminOrReadOnly(BasePermission):
