@@ -1,5 +1,3 @@
-from incuna_test_utils.compat import wipe_id_fields_on_django_lt_17
-
 from user_management.models.tests import factories, utils
 from ..models import AuthToken
 
@@ -8,17 +6,16 @@ class TestAuthToken(utils.APIRequestTestCase):
     model = AuthToken
 
     def test_fields(self):
-        fields = self.model._meta.get_all_field_names()
+        fields = {field.name for field in self.model._meta.get_fields()}
 
-        expected = wipe_id_fields_on_django_lt_17((
+        expected = (
             # Inherited from subclassed model
             'key',
             'user',
-            'user_id',
             'created',
 
             'expires',
-        ))
+        )
 
         self.assertCountEqual(fields, expected)
 
