@@ -1,5 +1,5 @@
 from django.core.cache import cache
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from mock import patch
 from rest_framework import status
 from rest_framework.test import APIRequestFactory
@@ -7,20 +7,26 @@ from rest_framework.test import APIRequestFactory
 from user_management.api import views
 from user_management.models.tests.factories import UserFactory
 from user_management.models.tests.utils import APIRequestTestCase
+from .. import throttling
 
 THROTTLE_RATE_PATH = 'rest_framework.throttling.ScopedRateThrottle.THROTTLE_RATES'
 
 
-class GetAuthTokenTest(APIRequestTestCase):
+class ClearCacheMixin:
+    """Clear cache on `tearDown`.
+
+    `django-rest-framework` puts a successful (not throttled) request into a cache."""
+    def tearDown(self):
+        cache.clear()
+
+
+class GetAuthTokenTest(ClearCacheMixin, APIRequestTestCase):
+    """Test `GetAuthToken` is throttled."""
     throttle_expected_status = status.HTTP_429_TOO_MANY_REQUESTS
     view_class = views.GetAuthToken
 
     def setUp(self):
-        self.auth_url = reverse('user_management_api:auth')
-
-    def tearDown(self):
-        # DRF puts a successful (not throttled) request onto a cache
-        cache.clear()
+        self.auth_url = reverse('user_management_api_core:auth')
 
     @patch(THROTTLE_RATE_PATH, new={'logins': '1/minute'})
     def test_user_auth_throttle(self):
@@ -29,14 +35,16 @@ class GetAuthTokenTest(APIRequestTestCase):
             'username': 'jimmy@example.com',
             'password': 'password;lol',
         }
-        request = self.create_request('post', auth=False, data=data)
         view = self.view_class.as_view()
 
         # no token attached hence HTTP 400
+        request = self.create_request('post', auth=False, data=data)
         response = view(request)
         self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)
 
         # request should be throttled now
+        # (new request created to prevent django.http.request.RawPostDataException)
+        request = self.create_request('post', auth=False, data=data)
         response = view(request)
         self.assertEqual(response.status_code, self.throttle_expected_status)
 
@@ -72,14 +80,31 @@ class GetAuthTokenTest(APIRequestTestCase):
         response = self.view_class.as_view()(request)
         self.assertEqual(response.status_code, self.throttle_expected_status)
 
+    @patch(THROTTLE_RATE_PATH, new={'logins': '1/minute'})
+    def test_authenticated_user_not_throttled(self):
+        """An authenticated user is not throttled by UsernameLoginRateThrottle."""
 
-class TestPasswordResetEmail(APIRequestTestCase):
+        class View(self.view_class):
+            throttle_classes = [throttling.UsernameLoginRateThrottle]
+
+        view = View.as_view()
+
+        # We are not throttled here
+        request = self.create_request('post', data={})
+        response = view(request)
+        self.assertNotEqual(response.status_code, self.throttle_expected_status)
+
+        # Or here
+        # (new request created to prevent django.http.request.RawPostDataException)
+        request = self.create_request('post', data={})
+        response = view(request)
+        self.assertNotEqual(response.status_code, self.throttle_expected_status)
+
+
+class TestPasswordResetEmail(ClearCacheMixin, APIRequestTestCase):
+    """Test `PasswordResetEmail` is throttled."""
     view_class = views.PasswordResetEmail
 
-    def tearDown(self):
-        # DRF puts a successful (not throttled) request onto a cache
-        cache.clear()
-
     @patch(THROTTLE_RATE_PATH, new={'passwords': '1/minute'})
     def test_post_rate_limit(self):
         """Ensure the POST requests are rate limited."""
@@ -96,3 +121,36 @@ class TestPasswordResetEmail(APIRequestTestCase):
         # request is throttled
         response = view(request)
         self.assertEqual(response.status_code, status.HTTP_429_TOO_MANY_REQUESTS)
+
+
+class TestResendConfirmationEmail(ClearCacheMixin, APIRequestTestCase):
+    """Test `ResendConfirmationEmail` is throttled."""
+    view_class = views.ResendConfirmationEmail
+
+    @patch(THROTTLE_RATE_PATH, new={'confirmations': '1/minute'})
+    def test_post_rate_limit(self):
+        """Assert POST requests are rate limited."""
+        user = UserFactory.create()
+        data = {'email': user.email}
+
+        request = self.create_request('post', data=data, auth=False)
+        view = self.view_class.as_view()
+
+        response = view(request)
+        self.assertEqual(response.status_code, status.HTTP_204_NO_CONTENT)
+
+        # Duplicate the request here as we are accessing request.data twice. To
+        # get the `request.data`, `djangorestframework` `read` the `POST` request
+        # (a stream) without rewinding the stream.
+        # This was producing an `Assertion` error only happening in test where
+        # calling the `view` with the same `request` twice is returning:
+        # {'detail': 'JSON parse error - No JSON object could be decoded'}`
+        # https://github.com/tomchristie/django-rest-framework/blob/650a91ac24cbd3e5b4ad5d7d7c6706fdf6160a78/rest_framework/parsers.py#L60-L64
+        request = self.create_request('post', data=data, auth=False)
+        view = self.view_class.as_view()
+        response = view(request)
+        self.assertEqual(
+            response.status_code,
+            status.HTTP_429_TOO_MANY_REQUESTS,
+            msg=response.data,
+        )
