@@ -1,52 +1,123 @@
 import datetime
 import re
+from collections import OrderedDict
 
-from django.contrib.auth import get_user_model
+from django.contrib.auth import get_user_model, signals
 from django.contrib.auth.hashers import check_password
 from django.contrib.auth.tokens import default_token_generator
+from django.contrib.sites.models import Site
 from django.core import mail
 from django.core.cache import cache
-from django.core.urlresolvers import reverse
+from django.test import override_settings
+from django.urls import reverse
 from django.utils import timezone
 from django.utils.encoding import force_bytes
 from django.utils.http import urlsafe_base64_encode
-from mock import patch
+from mock import MagicMock, patch
 from rest_framework import status
 from rest_framework.test import APIRequestFactory
 
 from user_management.api import models, views
+from user_management.api.tests.test_throttling import THROTTLE_RATE_PATH
 from user_management.models.tests.factories import AuthTokenFactory, UserFactory
 from user_management.models.tests.models import BasicUser
 from user_management.models.tests.utils import APIRequestTestCase
-
+from user_management.tests.utils import iso_8601
 
 User = get_user_model()
 TEST_SERVER = 'http://testserver'
+SEND_METHOD = 'user_management.utils.notifications.incuna_mail.send'
+EMAIL_CONTEXT = 'user_management.utils.notifications.password_reset_email_context'
+REGISTRATION_SERIALIZER_META_MODEL = (
+    'user_management.api.serializers.RegistrationSerializer.Meta.model'
+)
 
 
 class GetAuthTokenTest(APIRequestTestCase):
     model = models.AuthToken
     view_class = views.GetAuthToken
 
+    def setUp(self):
+        self.username = 'Test@example.com'
+        self.password = 'myepicstrongpassword'
+        self.data = {'username': self.username, 'password': self.password}
+
     def tearDown(self):
         cache.clear()
 
     def test_post(self):
-        username = 'Test@example.com'
-        password = 'myepicstrongpassword'
-        UserFactory.create(email=username.lower(), password=password)
+        """Assert user can sign in"""
+        UserFactory.create(email=self.username, password=self.password)
 
-        data = {'username': username, 'password': password}
-        request = self.create_request('post', auth=False, data=data)
+        request = self.create_request('post', auth=False, data=self.data)
         view = self.view_class.as_view()
         response = view(request)
         self.assertEqual(
             response.status_code, status.HTTP_200_OK, msg=response.data)
 
         # Ensure user has a token now
-        token = self.model.objects.get(user__email=username.lower())
+        token = self.model.objects.get()
         self.assertEqual(response.data['token'], token.key)
 
+    def test_post_last_login_updates(self):
+        """Authenticating updates the user's last_login."""
+        user = UserFactory.create(
+            email=self.username,
+            password=self.password,
+        )
+        previous_last_login = user.last_login
+        now = timezone.now()
+        request = self.create_request('post', auth=False, data=self.data)
+        self.view_class.as_view()(request)
+        user = User.objects.get(pk=user.pk)
+        self.assertGreater(user.last_login, now)
+        self.assertNotEqual(user.last_login, previous_last_login)
+
+    def test_post_non_existing_user(self):
+        """Assert non existing raises an error."""
+        request = self.create_request('post', auth=False, data=self.data)
+        view = self.view_class.as_view()
+        response = view(request)
+        self.assertEqual(
+            response.status_code,
+            status.HTTP_400_BAD_REQUEST,
+            msg=response.data,
+        )
+        expected = 'Unable to log in with provided credentials.'
+        self.assertIn(expected, response.data['non_field_errors'])
+        self.assertNotIn('token', response.data)
+
+    def test_post_user_not_confirmed(self):
+        """Assert non active users can not log in."""
+        UserFactory.create(email=self.username, password=self.password, is_active=False)
+
+        request = self.create_request('post', auth=False, data=self.data)
+        view = self.view_class.as_view()
+        response = view(request)
+        self.assertEqual(
+            response.status_code,
+            status.HTTP_400_BAD_REQUEST,
+            msg=response.data,
+        )
+        expected = 'Unable to log in with provided credentials.'
+        self.assertIn(expected, response.data['non_field_errors'])
+        self.assertNotIn('token', response.data)
+
+    def test_post_no_data(self):
+        """Assert sending no data raise an error."""
+        request = self.create_request('post', auth=False, data={})
+        view = self.view_class.as_view()
+        response = view(request)
+        self.assertEqual(
+            response.status_code,
+            status.HTTP_400_BAD_REQUEST,
+            msg=response.data,
+        )
+        expected = 'This field is required.'
+        self.assertIn(expected, response.data['username'])
+        self.assertIn(expected, response.data['password'])
+        self.assertNotIn('token', response.data)
+
     def test_delete(self):
         someday = timezone.now() + datetime.timedelta(days=1)
         user = UserFactory.create()
@@ -65,6 +136,31 @@ class GetAuthTokenTest(APIRequestTestCase):
         with self.assertRaises(self.model.DoesNotExist):
             self.model.objects.get(pk=token.pk)
 
+    def test_delete_user_logged_out_signal(self):
+        """Send the user_logged_out signal if a user deletes their Auth Token."""
+        handler = MagicMock()
+        signals.user_logged_out.connect(handler)
+
+        someday = timezone.now() + datetime.timedelta(days=1)
+        user = UserFactory.create()
+        token = AuthTokenFactory.create(user=user, expires=someday)
+
+        # Custom auth header containing token
+        auth = 'Token ' + token.key
+        request = self.create_request(
+            'delete',
+            user=user,
+            HTTP_AUTHORIZATION=auth,
+        )
+        response = self.view_class.as_view()(request)
+
+        handler.assert_called_once_with(
+            signal=signals.user_logged_out,
+            sender=views.GetAuthToken,
+            request=response.renderer_context['request'],
+            user=user,
+        )
+
     def test_delete_no_token(self):
         request = self.create_request('delete')
         response = self.view_class.as_view()(request)
@@ -90,9 +186,16 @@ class GetAuthTokenTest(APIRequestTestCase):
         response = self.view_class.as_view()(request)
         self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)
 
+    def test_unknown_token(self):
+        """An unknown token is accepted silently."""
+        auth = 'Token unknown'
+        request = self.create_request('delete', HTTP_AUTHORIZATION=auth)
+        response = self.view_class.as_view()(request)
+        self.assertEqual(response.status_code, status.HTTP_204_NO_CONTENT)
+
     def test_user_auth_method_not_allowed(self):
         """Ensure GET requests are not allowed."""
-        auth_url = reverse('user_management_api:auth')
+        auth_url = reverse('user_management_api_core:auth')
         request = APIRequestFactory().get(auth_url)
         response = self.view_class.as_view()(request)
 
@@ -129,9 +232,8 @@ class TestRegisterView(APIRequestTestCase):
         email = mail.outbox[0]
         verify_url_regex = re.compile(
             r'''
-                http://example\.com/\#/register/verify/
-                [0-9A-Za-z_\-]+/  # uid
-                [0-9A-Za-z]{1,13}-[0-9A-Za-z]{1,20}/  # token
+                https://example\.com/\#/register/verify/
+                [0-9A-Za-z:\-_]+/  # token
             ''',
             re.VERBOSE,
         )
@@ -148,11 +250,10 @@ class TestRegisterView(APIRequestTestCase):
         # Password should validate
         self.assertTrue(check_password(self.data['password'], user.password))
 
-    @patch('user_management.api.serializers.RegistrationSerializer.Meta.model',
-           new=BasicUser)
+    @patch(REGISTRATION_SERIALIZER_META_MODEL, new=BasicUser)
     def test_unauthenticated_user_post_no_verify_email(self):
         """
-        An email should not be sent if email_verification_required is False.
+        An email should not be sent if email_verified is True.
         """
         request = self.create_request('post', auth=False, data=self.data)
 
@@ -197,7 +298,7 @@ class TestRegisterView(APIRequestTestCase):
 
         self.assertTrue('email' in response.data, msg=response.data)
 
-        self.assertFalse(User.objects.count() > 1)
+        self.assertEqual(User.objects.count(), 1)
 
 
 class TestPasswordResetEmail(APIRequestTestCase):
@@ -209,6 +310,8 @@ class TestPasswordResetEmail(APIRequestTestCase):
     def test_existent_email(self):
         email = 'exists@example.com'
         user = UserFactory.create(email=email)
+        context = {}
+        site = Site.objects.get_current()
 
         request = self.create_request(
             'post',
@@ -216,11 +319,21 @@ class TestPasswordResetEmail(APIRequestTestCase):
             auth=False,
         )
         view = self.view_class.as_view()
-        with patch.object(self.view_class, 'send_email') as send_email:
-            response = view(request)
+        with patch(EMAIL_CONTEXT) as get_context:
+            get_context.return_value = context
+            with patch(SEND_METHOD) as send_email:
+                response = view(request)
         self.assertEqual(response.status_code, status.HTTP_204_NO_CONTENT)
 
-        send_email.assert_called_once_with(user)
+        expected = {
+            'to': user.email,
+            'template_name': 'user_management/password_reset_email.txt',
+            'html_template_name': 'user_management/password_reset_email.html',
+            'subject': '{} password reset'.format(site.domain),
+            'context': context,
+            'headers': {},
+        }
+        send_email.assert_called_once_with(**expected)
 
     def test_authenticated(self):
         request = self.create_request('post', auth=True)
@@ -238,7 +351,7 @@ class TestPasswordResetEmail(APIRequestTestCase):
             auth=False,
         )
         view = self.view_class.as_view()
-        with patch.object(self.view_class, 'send_email') as send_email:
+        with patch(SEND_METHOD) as send_email:
             response = view(request)
         self.assertEqual(response.status_code, status.HTTP_204_NO_CONTENT)
 
@@ -250,15 +363,18 @@ class TestPasswordResetEmail(APIRequestTestCase):
         response = view(request)
         self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)
 
-    def test_send_email(self):
-        email = 'test@example.com'
-        user = UserFactory.create(
-            email=email,
-            # Don't send the verification email
-            email_verification_required=False,
-        )
+    def test_email_content(self):
+        """Assert email content is output correctly."""
+        email = 'exists@example.com'
+        user = UserFactory.create(email=email)
 
-        self.view_class().send_email(user)
+        request = self.create_request(
+            'post',
+            data={'email': email},
+            auth=False,
+        )
+        view = self.view_class.as_view()
+        view(request)
 
         self.assertEqual(len(mail.outbox), 1)
 
@@ -268,6 +384,19 @@ class TestPasswordResetEmail(APIRequestTestCase):
         self.assertIn('auth/password_reset/confirm/', sent_mail.body)
         self.assertIn('https://', sent_mail.body)
 
+    @override_settings(DUM_PASSWORD_RESET_SUBJECT='overridden subject')
+    def test_email_settings_subject(self):
+        """Assert email content is output correctly."""
+        user = UserFactory.create()
+        request = self.create_request('post', auth=False, data={'email': user.email})
+        view = self.view_class.as_view()
+        view(request)
+
+        self.assertEqual(len(mail.outbox), 1)
+
+        sent_mail = mail.outbox[0]
+        self.assertEqual('overridden subject', sent_mail.subject)
+
     def test_options(self):
         """
         Ensure information about email field is included in options request.
@@ -279,15 +408,15 @@ class TestPasswordResetEmail(APIRequestTestCase):
         response = view(request)
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
-        expected_post_options = {
-            'email': {
-                'type': 'email',
-                'required': True,
-                'read_only': False,
-                'label': 'Email address',
-                'max_length': 511,
-            },
-        }
+        expected_post_options = OrderedDict((
+            ('email', OrderedDict((
+                ('type', 'email'),
+                ('required', True),
+                ('read_only', False),
+                ('label', 'Email address'),
+                ('max_length', 511),
+            ))),
+        ))
         self.assertEqual(
             response.data['actions']['POST'],
             expected_post_options,
@@ -328,8 +457,8 @@ class TestPasswordReset(APIRequestTestCase):
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
     def test_put(self):
-        old_password = 'old_password'
-        new_password = 'new_password'
+        old_password = '0ld_passworD'
+        new_password = 'n3w_Password'
         user = UserFactory.create(password=old_password)
 
         token = default_token_generator.make_token(user)
@@ -349,8 +478,8 @@ class TestPasswordReset(APIRequestTestCase):
         self.assertTrue(user.check_password(new_password))
 
     def test_password_mismatch(self):
-        old_password = 'old_password'
-        new_password = 'new_password'
+        old_password = '0ld_passworD'
+        new_password = 'n3w_Password'
         invalid_password = 'different_new_password'
         user = UserFactory.create(password=old_password)
 
@@ -380,7 +509,7 @@ class TestPasswordReset(APIRequestTestCase):
         request = self.create_request('put', auth=False)
         view = self.view_class.as_view()
         response = view(request, uidb64=invalid_uid)
-        self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
+        self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)
 
     def test_put_invalid_token(self):
         user = UserFactory.create()
@@ -391,17 +520,17 @@ class TestPasswordReset(APIRequestTestCase):
         request = self.create_request('put', auth=False)
         view = self.view_class.as_view()
         response = view(request, uidb64=uid, token=token)
-        self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
+        self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)
 
     def test_full_stack_wrong_url(self):
         user = UserFactory.create()
         token = default_token_generator.make_token(user)
         uid = urlsafe_base64_encode(b'0')  # Invalid uid, therefore bad url
 
-        view_name = 'user_management_api:password_reset_confirm'
+        view_name = 'user_management_api_core:password_reset_confirm'
         url = reverse(view_name, kwargs={'uidb64': uid, 'token': token})
         response = self.client.put(url)
-        self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
+        self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)
 
         self.assertTrue(hasattr(response, 'accepted_renderer'))
 
@@ -410,8 +539,8 @@ class TestPasswordChange(APIRequestTestCase):
     view_class = views.PasswordChange
 
     def test_update(self):
-        old_password = 'old_password'
-        new_password = 'new_password'
+        old_password = '0ld_passworD'
+        new_password = 'n3w_Password'
 
         user = UserFactory.create(password=old_password)
 
@@ -431,8 +560,8 @@ class TestPasswordChange(APIRequestTestCase):
         self.assertTrue(user.check_password(new_password))
 
     def test_update_anonymous(self):
-        old_password = 'old_password'
-        new_password = 'new_password'
+        old_password = '0ld_passworD'
+        new_password = 'n3w_Password'
 
         request = self.create_request(
             'put',
@@ -448,8 +577,8 @@ class TestPasswordChange(APIRequestTestCase):
         self.assertEqual(response.status_code, status.HTTP_401_UNAUTHORIZED)
 
     def test_update_wrong_old_password(self):
-        old_password = 'old_password'
-        new_password = 'new_password'
+        old_password = '0ld_passworD'
+        new_password = 'n3w_Password'
 
         user = UserFactory.create(password=old_password)
 
@@ -469,8 +598,8 @@ class TestPasswordChange(APIRequestTestCase):
         self.assertTrue(user.check_password(old_password))
 
     def test_update_invalid_new_password(self):
-        old_password = 'old_password'
-        new_password = '2short'
+        old_password = '0ld_passworD'
+        new_password = '2Short'
 
         user = UserFactory.create(password=old_password)
 
@@ -490,8 +619,8 @@ class TestPasswordChange(APIRequestTestCase):
         self.assertTrue(user.check_password(old_password))
 
     def test_update_mismatched_passwords(self):
-        old_password = 'old_password'
-        new_password = 'new_password'
+        old_password = '0ld_passworD'
+        new_password = 'n3w_Password'
         invalid_password = 'different_new_password'
 
         user = UserFactory.create(password=old_password)
@@ -516,89 +645,46 @@ class TestVerifyAccountView(APIRequestTestCase):
     view_class = views.VerifyAccountView
 
     def test_post_authenticated(self):
+        """Assert authenticated user can verify its email."""
         user = UserFactory.create()
-        token = default_token_generator.make_token(user)
-        uid = urlsafe_base64_encode(force_bytes(user.pk))
+        token = user.generate_validation_token()
 
-        request = self.create_request('post', auth=True)
+        request = self.create_request('post', user=user, auth=True)
         view = self.view_class.as_view()
-        response = view(request, uidb64=uid, token=token)
+        response = view(request, token=token)
         self.assertEqual(response.status_code, status.HTTP_201_CREATED)
 
         updated_user = User.objects.get(pk=user.pk)
-        self.assertFalse(updated_user.email_verification_required)
+        self.assertTrue(updated_user.email_verified)
         self.assertTrue(updated_user.is_active)
 
     def test_post_unauthenticated(self):
+        """
+        Assert an unauthenticated user can verify its email.
+
+        Regression test for https://github.com/incuna/django-user-management/pull/120.
+        """
         user = UserFactory.create()
-        token = default_token_generator.make_token(user)
-        uid = urlsafe_base64_encode(force_bytes(user.pk))
+        token = user.generate_validation_token()
 
         request = self.create_request('post', auth=False)
         view = self.view_class.as_view()
-        response = view(request, uidb64=uid, token=token)
+        response = view(request, token=token)
         self.assertEqual(response.status_code, status.HTTP_201_CREATED)
 
         updated_user = User.objects.get(pk=user.pk)
-        self.assertFalse(updated_user.email_verification_required)
+        self.assertTrue(updated_user.email_verified)
         self.assertTrue(updated_user.is_active)
 
-    def test_post_invalid_user(self):
-        # There should never be a user with pk 0
-        invalid_uid = urlsafe_base64_encode(b'0')
-
-        request = self.create_request('post')
-        view = self.view_class.as_view()
-        response = view(request, uidb64=invalid_uid)
-        self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
-
-    def test_post_invalid_token(self):
-        user = UserFactory.create()
-        other_user = UserFactory.create()
-        token = default_token_generator.make_token(other_user)
-        uid = urlsafe_base64_encode(force_bytes(user.pk))
-
-        request = self.create_request('post')
-        view = self.view_class.as_view()
-        response = view(request, uidb64=uid, token=token)
-        self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
-
-    def test_post_verified_email(self):
-        user = UserFactory.create(email_verification_required=False)
-        token = default_token_generator.make_token(user)
-        uid = urlsafe_base64_encode(force_bytes(user.pk))
-
-        request = self.create_request('post')
-        view = self.view_class.as_view()
-        response = view(request, uidb64=uid, token=token)
-        self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
-
-    def test_post_different_user_logged_in(self):
-        user = UserFactory.create()
-        other_user = UserFactory.create()
-        token = default_token_generator.make_token(user)
-        uid = urlsafe_base64_encode(force_bytes(user.pk))
-
-        request = self.create_request('post', user=other_user)
-        view = self.view_class.as_view()
-        response = view(request, uidb64=uid, token=token)
-        self.assertEqual(response.status_code, status.HTTP_201_CREATED)
-
-        updated_user = User.objects.get(pk=user.pk)
-        self.assertFalse(updated_user.email_verification_required)
-
-        logged_in_user = User.objects.get(pk=other_user.pk)
-        self.assertTrue(logged_in_user.email_verification_required)
-
     def test_full_stack_wrong_url(self):
-        user = UserFactory.create()
-        token = default_token_generator.make_token(user)
-        uid = urlsafe_base64_encode(b'0')  # Invalid uid, therefore bad url
+        """Integration test to check a nonexistent email returns a bad request."""
+        user = UserFactory.build()
+        token = user.generate_validation_token()
 
-        view_name = 'user_management_api:verify_user'
-        url = reverse(view_name, kwargs={'uidb64': uid, 'token': token})
+        view_name = 'user_management_api_verify:verify_user'
+        url = reverse(view_name, kwargs={'token': token})
         response = self.client.post(url)
-        self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
+        self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)
 
         self.assertTrue(hasattr(response, 'accepted_renderer'))
 
@@ -610,7 +696,7 @@ class TestProfileDetail(APIRequestTestCase):
         expected = {
             'name': user.name,
             'email': user.email,
-            'date_joined': user.date_joined,
+            'date_joined': iso_8601(user.date_joined),
         }
         return expected
 
@@ -671,20 +757,30 @@ class TestProfileDetail(APIRequestTestCase):
         response = view(request)
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
+    def test_delete(self):
+        """Assert a user can delete its profile."""
+        request = self.create_request('delete')
+        view = self.view_class.as_view()
+        response = view(request)
+        self.assertEqual(response.status_code, status.HTTP_204_NO_CONTENT)
+
+        with self.assertRaises(User.DoesNotExist):
+            User.objects.get()
+
 
 class TestUserList(APIRequestTestCase):
     view_class = views.UserList
 
     def expected_data(self, user):
         url = reverse(
-            'user_management_api:user_detail',
+            'user_management_api_users:user_detail',
             kwargs={'pk': user.pk},
         )
         expected = {
             'url': TEST_SERVER + url,
             'name': user.name,
             'email': user.email,
-            'date_joined': user.date_joined,
+            'date_joined': iso_8601(user.date_joined),
         }
         return expected
 
@@ -740,14 +836,14 @@ class TestUserDetail(APIRequestTestCase):
 
     def expected_data(self, user):
         url = reverse(
-            'user_management_api:user_detail',
+            'user_management_api_users:user_detail',
             kwargs={'pk': user.pk},
         )
         expected = {
             'url': TEST_SERVER + url,
             'name': user.name,
             'email': user.email,
-            'date_joined': user.date_joined,
+            'date_joined': iso_8601(user.date_joined),
         }
         return expected
 
@@ -837,3 +933,105 @@ class TestUserDetail(APIRequestTestCase):
 
         user = User.objects.get()
         self.assertEqual(self.user, user)
+
+
+@patch(THROTTLE_RATE_PATH, new={'confirmations': '40/minute'})
+class ResendConfirmationEmailTest(APIRequestTestCase):
+    """Assert `ResendConfirmationEmail` behaves properly."""
+    view_class = views.ResendConfirmationEmail
+
+    def test_post(self):
+        """Assert user can request a new confirmation email."""
+        user = UserFactory.create()
+        data = {'email': user.email}
+        request = self.create_request('post', auth=False, data=data)
+        view = self.view_class.as_view()
+        response = view(request)
+        self.assertEqual(
+            response.status_code,
+            status.HTTP_204_NO_CONTENT,
+            msg=response.data,
+        )
+
+    def test_post_unknown_email(self):
+        """Assert unknown email raises an error."""
+        data = {'email': 'theman@theiron.mask'}
+        request = self.create_request('post', auth=False, data=data)
+        view = self.view_class.as_view()
+        response = view(request)
+        self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)
+        self.assertIn('email', response.data)
+
+    def test_post_email_already_verified(self):
+        """Assert email already verified does not trigger another email."""
+        user = UserFactory.create(email_verified=True)
+        request = self.create_request('post', auth=False, data={'email': user.email})
+        view = self.view_class.as_view()
+        response = view(request)
+        self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)
+        self.assertIn('email', response.data)
+
+    def test_send_email_unauthenticated(self):
+        """Assert unauthenticated user can receive a new confirmation email."""
+        user = UserFactory.create()
+        request = self.create_request('post', auth=False, data={'email': user.email})
+        view = self.view_class.as_view()
+        view(request)
+
+        self.assertEqual(len(mail.outbox), 1)
+        email = mail.outbox[0]
+
+        self.assertIn(user.email, email.to)
+        expected = 'https://example.com/#/register/verify/'
+        self.assertIn(expected, email.body)
+
+        expected = 'example.com account validate'
+        self.assertEqual(email.subject, expected)
+
+    def test_send_email_authenticated(self):
+        """Assert authenticated user can receive a new confirmation email."""
+        user = UserFactory.create()
+        request = self.create_request('post', user=user, data={'email': user.email})
+        view = self.view_class.as_view()
+        view(request)
+
+        self.assertEqual(len(mail.outbox), 1)
+        email = mail.outbox[0]
+
+        self.assertIn(user.email, email.to)
+        expected = 'https://example.com/#/register/verify/'
+        self.assertIn(expected, email.body)
+
+        expected = 'example.com account validate'
+        self.assertEqual(email.subject, expected)
+
+    @override_settings(DUM_VALIDATE_EMAIL_SUBJECT='overridden subject')
+    def test_send_email_subject_setting(self):
+        """Assert the subject is affected by the DUM_VALIDATE_EMAIL_SUBJECT setting."""
+        user = UserFactory.create()
+        request = self.create_request('post', auth=False, data={'email': user.email})
+        view = self.view_class.as_view()
+        view(request)
+
+        self.assertEqual(len(mail.outbox), 1)
+        email = mail.outbox[0]
+        self.assertEqual(email.subject, 'overridden subject')
+
+    def test_send_email_other_user(self):
+        """Assert a user can not request a confirmation email for another user."""
+        user, other_user = UserFactory.create_batch(2)
+        data = {'email': other_user.email}
+        request = self.create_request('post', user=user, data=data)
+        view = self.view_class.as_view()
+        response = view(request)
+
+        self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
+
+    def test_send_email_empty(self):
+        """Assert we delegate the error to the serializer if no email data was sent."""
+        data = {}
+        request = self.create_request('post', data=data)
+        view = self.view_class.as_view()
+        response = view(request)
+
+        self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
