@@ -20,16 +20,18 @@ class PostRequestThrottleMixin(object):
         return super(PostRequestThrottleMixin, self).allow_request(request, view)
 
 
-class LoginRateThrottle(
-        DefaultRateMixin,
-        PostRequestThrottleMixin,
-        ScopedRateThrottle):
+class ScopedRateThrottleBase(
+        DefaultRateMixin, PostRequestThrottleMixin, ScopedRateThrottle):
+    """Base class to define a scoped rate throttle on POST request."""
+
+
+class LoginRateThrottle(ScopedRateThrottleBase):
     default_rate = '10/hour'
 
 
 class UsernameLoginRateThrottle(LoginRateThrottle):
     def get_cache_key(self, request, view):
-        if request.user.is_authenticated():
+        if request.user.is_authenticated:
             return None  # Only throttle unauthenticated requests
 
         ident = request.POST.get('username')
@@ -42,8 +44,11 @@ class UsernameLoginRateThrottle(LoginRateThrottle):
         }
 
 
-class PasswordResetRateThrottle(
-        DefaultRateMixin,
-        PostRequestThrottleMixin,
-        ScopedRateThrottle):
+class PasswordResetRateThrottle(ScopedRateThrottleBase):
+    """Set `default_rate` for scoped rate POST requests on password reset."""
+    default_rate = '3/hour'
+
+
+class ResendConfirmationEmailRateThrottle(ScopedRateThrottleBase):
+    """Set `default_rate` for scoped rate POST requests on `ResendConfirmationEmail`."""
     default_rate = '3/hour'
