@@ -1,13 +1,12 @@
-from django.conf.urls import patterns, url
+from django.conf.urls import url
 
 from .. import views
 
 
-urlpatterns = patterns(
-    '',
+urlpatterns = [
     url(
         regex=r'^auth/?$',
         view=views.GetAuthToken.as_view(),
         name='auth',
     ),
-)
+]
