@@ -1,10 +1,10 @@
-from django.conf.urls import patterns, url
+from django.conf.urls import url
 
 from .. import views
 
 
-urlpatterns = patterns(
-    '',
+app_name = 'user_management_api_users'
+urlpatterns = [
     url(
         regex=r'^users/?$',
         view=views.UserList.as_view(),
@@ -15,4 +15,4 @@ urlpatterns = patterns(
         view=views.UserDetail.as_view(),
         name='user_detail'
     ),
-)
+]
