@@ -1,17 +1,16 @@
-from django.conf.urls import patterns, url
+from django.conf.urls import url
 from django.views.decorators.csrf import csrf_exempt
 
 from .. import views
 
 
-urlpatterns = patterns(
-    '',
+app_name = 'user_management_api_verify'
+urlpatterns = [
     url(
         regex=(
-            r'^verify_email/(?P<uidb64>[0-9A-Za-z_\-]+)/'
-            r'(?P<token>[0-9A-Za-z]{1,13}-[0-9A-Za-z]{1,20})/?$'
+            r'^verify_email/(?P<token>[0-9A-Za-z:\-_]+)/?$'
         ),
         view=csrf_exempt(views.VerifyAccountView.as_view()),
         name='verify_user',
     ),
-)
+]
