@@ -1,26 +1,31 @@
-from django.contrib.auth import get_user_model
+from django.contrib.auth import get_user_model, signals
 from django.contrib.auth.tokens import default_token_generator
-from django.contrib.sites.models import Site
-from django.http import Http404
-from django.utils.encoding import force_bytes, force_text
-from django.utils.http import urlsafe_base64_decode, urlsafe_base64_encode
+from django.utils.encoding import force_text
+from django.utils.http import urlsafe_base64_decode
 from django.utils.translation import ugettext_lazy as _
-from incuna_mail import send
-from rest_framework import generics, renderers, response, status, views
+from rest_framework import generics, response, status, views
 from rest_framework.authentication import get_authorization_header
 from rest_framework.authtoken.views import ObtainAuthToken
+from rest_framework.exceptions import PermissionDenied
 from rest_framework.permissions import AllowAny, IsAuthenticated
 
-from . import models, permissions, serializers, throttling
-
+from user_management.utils.views import VerifyAccountViewMixin
+from . import exceptions, models, permissions, serializers, throttling
 
 User = get_user_model()
 
 
 class GetAuthToken(ObtainAuthToken):
+    """
+    Obtain an authentication token.
+
+    Define a `POST` (create) method to authenticate a user using their `email` and
+    `password` and return a `token` if successful.
+    The `token` remains valid until `settings.AUTH_TOKEN_MAX_AGE` time has passed.
+
+    `DELETE` method removes the current `token` from the database.
+    """
     model = models.AuthToken
-    renderer_classes = (renderers.JSONRenderer, renderers.BrowsableAPIRenderer)
-    serializer_class = serializers.AuthTokenSerializer
     throttle_classes = [
         throttling.UsernameLoginRateThrottle,
         throttling.LoginRateThrottle,
@@ -30,9 +35,11 @@ class GetAuthToken(ObtainAuthToken):
     def post(self, request):
         """Create auth token. Differs from DRF that it always creates new token
         but not re-using them."""
-        serializer = self.serializer_class(data=request.DATA)
+        serializer = self.serializer_class(data=request.data)
         if serializer.is_valid():
-            token = self.model.objects.create(user=serializer.object['user'])
+            user = serializer.validated_data['user']
+            signals.user_logged_in.send(type(self), user=user, request=request)
+            token = self.model.objects.create(user=user)
             token.update_expiry()
             return response.Response({'token': token.key})
 
@@ -55,23 +62,31 @@ class GetAuthToken(ObtainAuthToken):
             return response.Response(msg, status=status.HTTP_400_BAD_REQUEST)
 
         try:
-            token = self.model.objects.get(key=auth[1])
+            token = self.model.objects.get(key=auth[1].decode('utf-8'))
         except self.model.DoesNotExist:
             pass
         else:
             token.delete()
+            signals.user_logged_out.send(
+                type(self),
+                user=token.user,
+                request=request,
+            )
         return response.Response(status=status.HTTP_204_NO_CONTENT)
 
 
 class UserRegister(generics.CreateAPIView):
+    """
+    Register a new `User`.
+
+    An email to validate the new account is sent if `email_verified`
+    is set to `False`.
+    """
     serializer_class = serializers.RegistrationSerializer
     permission_classes = [permissions.IsNotAuthenticated]
 
     def create(self, request, *args, **kwargs):
-        serializer = self.get_serializer(
-            data=request.DATA,
-            files=request.FILES,
-        )
+        serializer = self.get_serializer(data=request.data)
         if serializer.is_valid():
             return self.is_valid(serializer)
         return self.is_invalid(serializer)
@@ -83,9 +98,9 @@ class UserRegister(generics.CreateAPIView):
         )
 
     def is_valid(self, serializer):
-        serializer.save()
-        if serializer.object.email_verification_required:
-            serializer.object.send_validation_email()
+        user = serializer.save()
+        if not user.email_verified:
+            user.send_validation_email()
             ok_message = _(
                 'Your account has been created and an activation link sent ' +
                 'to your email address. Please check your email to continue.'
@@ -100,22 +115,20 @@ class UserRegister(generics.CreateAPIView):
 
 
 class PasswordResetEmail(generics.GenericAPIView):
+    """
+    Send a password reset email to a user on request.
+
+    A user can request a password request email by providing their email address.
+    If the user is not found no error is raised.
+    """
     permission_classes = [permissions.IsNotAuthenticated]
     template_name = 'user_management/password_reset_email.html'
     serializer_class = serializers.PasswordResetEmailSerializer
     throttle_classes = [throttling.PasswordResetRateThrottle]
     throttle_scope = 'passwords'
 
-    def email_context(self, site, user):
-        return {
-            'protocol': 'https',
-            'site': site,
-            'token': default_token_generator.make_token(user),
-            'uid': urlsafe_base64_encode(force_bytes(user.pk)),
-        }
-
     def post(self, request, *args, **kwargs):
-        serializer = self.get_serializer(data=request.DATA)
+        serializer = self.get_serializer(data=request.data)
         if not serializer.is_valid():
             return response.Response(
                 serializer.errors,
@@ -128,22 +141,18 @@ class PasswordResetEmail(generics.GenericAPIView):
         except User.DoesNotExist:
             pass
         else:
-            self.send_email(user)
+            user.send_password_reset()
 
         msg = _('Password reset request successful. Please check your email.')
         return response.Response(msg, status=status.HTTP_204_NO_CONTENT)
 
-    def send_email(self, user):
-        site = Site.objects.get_current()
-        send(
-            to=[user.email],
-            template_name=self.template_name,
-            subject=_('{domain} password reset').format(domain=site.domain),
-            context=self.email_context(site, user),
-        )
-
 
 class OneTimeUseAPIMixin(object):
+    """
+    Use a `uid` and a `token` to allow one-time access to a view.
+
+    Set user as a class attribute or raise an `InvalidExpiredToken`.
+    """
     def initial(self, request, *args, **kwargs):
         uidb64 = kwargs['uidb64']
         uid = urlsafe_base64_decode(force_text(uidb64))
@@ -151,11 +160,11 @@ class OneTimeUseAPIMixin(object):
         try:
             self.user = User.objects.get(pk=uid)
         except User.DoesNotExist:
-            raise Http404()
+            raise exceptions.InvalidExpiredToken()
 
         token = kwargs['token']
         if not default_token_generator.check_token(self.user, token):
-            raise Http404()
+            raise exceptions.InvalidExpiredToken()
 
         return super(OneTimeUseAPIMixin, self).initial(
             request,
@@ -165,6 +174,17 @@ class OneTimeUseAPIMixin(object):
 
 
 class PasswordReset(OneTimeUseAPIMixin, generics.UpdateAPIView):
+    """
+    Reset a user's password.
+
+    This view is generally called when a user has followed an email link to
+    reset a password.
+
+    This view will check first if the `uid` and `token` are valid.
+
+    `PasswordReset` is called with an `UPDATE` containing the new password
+    (`new_password` and `new_password2`).
+    """
     permission_classes = [permissions.IsNotAuthenticated]
     model = User
     serializer_class = serializers.PasswordResetSerializer
@@ -174,6 +194,12 @@ class PasswordReset(OneTimeUseAPIMixin, generics.UpdateAPIView):
 
 
 class PasswordChange(generics.UpdateAPIView):
+    """
+    Change a user's password.
+
+    Give ability to `PUT` (update) a password when authenticated by submitting current
+    password.
+    """
     model = User
     permission_classes = (IsAuthenticated,)
     serializer_class = serializers.PasswordChangeSerializer
@@ -182,25 +208,30 @@ class PasswordChange(generics.UpdateAPIView):
         return self.request.user
 
 
-class VerifyAccountView(OneTimeUseAPIMixin, views.APIView):
+class VerifyAccountView(VerifyAccountViewMixin, views.APIView):
+    """
+    Verify a new user's email address.  Accepts a POST request with a token in the URL.
+    """
     permission_classes = [AllowAny]
-    ok_message = _('Your account has been verified.')
+
+    def initial(self, request, *args, **kwargs):
+        self.verify_token(request, *args, **kwargs)
+        return super(VerifyAccountView, self).initial(request, *args, **kwargs)
 
     def post(self, request, *args, **kwargs):
-        if not self.user.email_verification_required:
-            return response.Response(status=status.HTTP_403_FORBIDDEN)
-
-        self.user.email_verification_required = False
-        self.user.is_active = True
-        self.user.save()
-
+        self.activate_user()
         return response.Response(
             data={'data': self.ok_message},
             status=status.HTTP_201_CREATED,
         )
 
 
-class ProfileDetail(generics.RetrieveUpdateAPIView):
+class ProfileDetail(generics.RetrieveUpdateDestroyAPIView):
+    """
+    Allow a user to view and edit their profile information.
+
+    `GET`, `UPDATE` and `DELETE` current logged-in user.
+    """
     model = User
     permission_classes = (IsAuthenticated,)
     serializer_class = serializers.ProfileSerializer
@@ -210,12 +241,61 @@ class ProfileDetail(generics.RetrieveUpdateAPIView):
 
 
 class UserList(generics.ListCreateAPIView):
-    model = User
+    """
+    Return information about all users and allow creation of new users.
+
+    Allow to `GET` a list users and to `POST` new user for admin user only.
+    """
+    queryset = User.objects.all()
     permission_classes = (IsAuthenticated, permissions.IsAdminOrReadOnly)
     serializer_class = serializers.UserSerializerCreate
 
 
 class UserDetail(generics.RetrieveUpdateDestroyAPIView):
-    model = User
+    """
+    Display information about a user.
+
+    Allow admin users to update or delete user information.
+    """
+    queryset = User.objects.all()
     permission_classes = (IsAuthenticated, permissions.IsAdminOrReadOnly)
     serializer_class = serializers.UserSerializer
+
+
+class ResendConfirmationEmail(generics.GenericAPIView):
+    """
+    Resend a confirmation email.
+
+    `POST` request to resend a confirmation email for existing user. If user is
+    authenticated the email sent should match.
+    """
+    permission_classes = [AllowAny]
+    serializer_class = serializers.ResendConfirmationEmailSerializer
+    throttle_classes = [throttling.ResendConfirmationEmailRateThrottle]
+    throttle_scope = 'confirmations'
+
+    def initial(self, request, *args, **kwargs):
+        """Disallow users other than the user whose email is being reset."""
+        email = request.data.get('email')
+        if request.user.is_authenticated and email != request.user.email:
+            raise PermissionDenied()
+
+        return super(ResendConfirmationEmail, self).initial(
+            request,
+            *args,
+            **kwargs
+        )
+
+    def post(self, request, *args, **kwargs):
+        """Validate `email` and send a request to confirm it."""
+        serializer = self.serializer_class(data=request.data)
+
+        if not serializer.is_valid():
+            return response.Response(
+                serializer.errors,
+                status=status.HTTP_400_BAD_REQUEST,
+            )
+
+        serializer.user.send_validation_email()
+        msg = _('Email confirmation sent.')
+        return response.Response(msg, status=status.HTTP_204_NO_CONTENT)
