@@ -3,15 +3,17 @@ import factory
 from django.contrib.auth import get_user_model
 
 from user_management.api.models import AuthToken
+from user_management.models.tests.models import VerifyEmailUser
 
 
 class UserFactory(factory.DjangoModelFactory):
-    FACTORY_FOR = get_user_model()
-
     name = factory.Sequence('Test User {}'.format)
     email = factory.Sequence('email{}@example.com'.format)
     is_active = True
 
+    class Meta:
+        model = get_user_model()
+
     @factory.post_generation
     def password(self, create, extracted='default password', **kwargs):
         self.raw_password = extracted
@@ -20,8 +22,16 @@ class UserFactory(factory.DjangoModelFactory):
             self.save()
 
 
-class AuthTokenFactory(factory.DjangoModelFactory):
-    FACTORY_FOR = AuthToken
+class VerifyEmailUserFactory(UserFactory):
+    email_verified = False
 
+    class Meta:
+        model = VerifyEmailUser
+
+
+class AuthTokenFactory(factory.DjangoModelFactory):
     key = factory.Sequence('key{}'.format)
     user = factory.SubFactory(UserFactory)
+
+    class Meta:
+        model = AuthToken
