@@ -1,29 +1,24 @@
 # -*- coding: utf-8 -*-
 
-import unittest
-
-import django
-from django.contrib.auth.tokens import default_token_generator
 from django.contrib.sites.models import Site
 from django.core import checks
 from django.db.models import TextField
 from django.db.utils import IntegrityError
 from django.test import TestCase
-from django.utils import six, timezone
-from django.utils.encoding import force_bytes
-from django.utils.http import urlsafe_base64_encode
-from mock import patch
+from django.utils import timezone
+
+from mock import Mock, patch
 
 from user_management.models.tests import utils
+from user_management.utils.notifications import validation_email_context
 from . import models
 from .factories import UserFactory
 from .. import mixins
 
 
-skip_if_checks_unavailable = unittest.skipIf(
-    django.VERSION < (1, 7),
-    'Checks only available in django>=1.7',
-)
+PASSWORD_CONTEXT = 'user_management.utils.notifications.password_reset_email_context'
+VALIDATION_CONTEXT = 'user_management.utils.notifications.validation_email_context'
+SEND_METHOD = 'user_management.utils.notifications.incuna_mail.send'
 
 
 class TestUser(utils.APIRequestTestCase):
@@ -32,14 +27,14 @@ class TestUser(utils.APIRequestTestCase):
 
     def test_fields(self):
         """Do we have the fields we expect?"""
-        fields = self.model._meta.get_all_field_names()
+        fields = {field.name for field in self.model._meta.get_fields()}
         expected = {
             # On model
             'id',
             'name',
             'date_joined',
             'email',
-            'email_verification_required',
+            'email_verified',
             'is_active',
             'is_staff',
             'is_superuser',
@@ -61,7 +56,7 @@ class TestUser(utils.APIRequestTestCase):
         """Does "User.__str__()" work as expected?"""
         expected = 'Leopold Stotch'
         user = self.model(name=expected)
-        self.assertEqual(six.text_type(user), expected)
+        self.assertEqual(str(user), expected)
 
     def test_name_methods(self):
         """Do "User.get_full_name()" & "get_short_name()" work as expected?"""
@@ -70,6 +65,11 @@ class TestUser(utils.APIRequestTestCase):
         self.assertEqual(user.get_full_name(), expected)
         self.assertEqual(user.get_short_name(), expected)
 
+    def test_case_insensitive_uniqueness(self):
+        self.model(email='CAPS@example.com').save()
+        with self.assertRaises(IntegrityError):
+            self.model(email='caps@example.com').save()
+
 
 class TestUserManager(TestCase):
     manager = models.User.objects
@@ -114,7 +114,7 @@ class TestUserManager(TestCase):
         self.assertFalse(user.is_active)
         self.assertFalse(user.is_staff)
         self.assertFalse(user.is_superuser)
-        self.assertTrue(user.email_verification_required)
+        self.assertFalse(user.email_verified)
 
         # Check that the time is correct (or at least, in range)
         time_after = timezone.now()
@@ -174,108 +174,60 @@ class TestVerifyEmailMixin(TestCase):
         user = self.model()
         user.save()
         self.assertFalse(user.is_active)
-        self.assertTrue(user.email_verification_required)
-
-    def test_get_email_subject(self):
-        domain = 'http://example.com'
-        expected_subject = '{} account validate'.format(domain)
-        user = self.model()
-
-        self.assertEqual(user.get_email_subject(domain), expected_subject)
-
-    def test_get_email_subject_custom_template(self):
-        domain = 'http://example.com'
-        subject_template = '{domain} register'
-        expected_subject = subject_template.format(domain=domain)
-        user = self.model()
-        user.EMAIL_SUBJECT = subject_template
-
-        self.assertEqual(user.get_email_subject(domain), expected_subject)
+        self.assertFalse(user.email_verified)
 
     def test_email_context(self):
-        site = Site.objects.get_current()
-        user = self.model()
-        uid = urlsafe_base64_encode(force_bytes(user.pk))
+        """Assert `password_reset_email_context` returns the correct data."""
+        mocked_user = Mock()
+        mocked_site = Mock()
 
-        with patch.object(default_token_generator, 'make_token') as make_token:
-            context = user.email_context(site)
+        class DummyNotification:
+            user = mocked_user
+            site = mocked_site
 
-        expected_context = {'uid': uid, 'token': make_token(), 'site': site}
+        notification = DummyNotification()
+        context = validation_email_context(notification)
+
+        expected_context = {
+            'protocol': 'https',
+            'token': mocked_user.generate_validation_token(),
+            'site': mocked_site,
+        }
         self.assertEqual(context, expected_context)
 
-    def test_email_kwargs_default(self):
-        context = {}
-        domain = 'http://example.com'
-        subject = '{} account validate'.format(domain)
-        text_template = 'user_management/account_validation_email.txt'
-        html_template = 'user_management/account_validation_email.html'
-
-        user = self.model(email='dummy@example.com')
-
-        kwargs = user.email_kwargs(context, domain)
-
-        expected_kwargs = {
-            'to': [user.email],
-            'template_name': text_template,
-            'html_template_name': html_template,
-            'subject': subject,
-            'context': context,
-        }
-        self.assertEqual(kwargs, expected_kwargs)
-
-    def test_email_kwargs_custom(self):
-        context = {}
-        domain = 'http://example.com'
-        subject = '{} account validate'.format(domain)
-        text_template = 'user_management/validation_email.txt'
-        html_template = 'user_management/validation_email.html'
-
-        user = self.model(email='dummy@example.com')
-        user.TEXT_EMAIL_TEMPLATE = text_template
-        user.HTML_EMAIL_TEMPLATE = html_template
-
-        kwargs = user.email_kwargs(context, domain)
-
-        expected_kwargs = {
-            'to': [user.email],
-            'template_name': text_template,
-            'html_template_name': html_template,
-            'subject': subject,
-            'context': context,
-        }
-        self.assertEqual(kwargs, expected_kwargs)
-
     def test_send_validation_email(self):
         context = {}
-        kwargs = {'context': context}
         site = Site.objects.get_current()
-        user = self.model()
+        user = self.model(email='email@email.email')
 
-        with patch.object(user, 'email_context') as get_context:
+        with patch(VALIDATION_CONTEXT) as get_context:
             get_context.return_value = context
-            with patch.object(user, 'email_kwargs') as get_kwargs:
-                get_kwargs.return_value = kwargs
-                with patch('user_management.models.mixins.send') as send:
-                    user.send_validation_email()
+            with patch(SEND_METHOD) as send:
+                user.send_validation_email()
 
-        get_kwargs.assert_called_once_with(context, site.domain)
-        send.assert_called_once_with(**kwargs)
+        expected = {
+            'to': user.email,
+            'template_name': 'user_management/account_validation_email.txt',
+            'html_template_name': 'user_management/account_validation_email.html',
+            'subject': '{} account validate'.format(site.domain),
+            'context': context,
+            'headers': {},
+        }
+        send.assert_called_once_with(**expected)
 
     def test_verified_email(self):
-        user = self.model(email_verification_required=False)
+        user = self.model(email_verified=True)
 
-        with patch('user_management.models.mixins.send') as send:
+        with patch(SEND_METHOD) as send:
             with self.assertRaises(ValueError):
                 user.send_validation_email()
 
         self.assertFalse(send.called)
 
-    @skip_if_checks_unavailable
     def test_manager_check_valid(self):
         errors = self.model.check()
         self.assertEqual(errors, [])
 
-    @skip_if_checks_unavailable
     def test_manager_check_invalid(self):
         class InvalidUser(self.model):
             objects = mixins.UserManager()
@@ -297,14 +249,14 @@ class TestCustomNameUser(utils.APIRequestTestCase):
 
     def test_fields(self):
         """Do we have the fields we expect?"""
-        fields = self.model._meta.get_all_field_names()
+        fields = {field.name for field in self.model._meta.get_fields()}
         expected = {
             # On model
             'id',
             'name',
             'date_joined',
             'email',
-            'email_verification_required',
+            'email_verified',
             'is_active',
             'is_staff',
             'last_login',
@@ -319,11 +271,36 @@ class TestCustomNameUser(utils.APIRequestTestCase):
         model = self.model(name=expected)
 
         self.assertEqual(model.get_full_name(), expected)
-        self.assertEqual(six.text_type(model), expected)
-        field = self.model._meta.get_field_by_name('name')[0]
+        self.assertEqual(str(model), expected)
+        field = self.model._meta.get_field('name')
         self.assertIsInstance(field, TextField)
 
-    @skip_if_checks_unavailable
     def test_manager_check_invalid(self):
         errors = self.model.check()
         self.assertEqual(errors, [])
+
+
+class TestCustomPasswordResetNotification(TestCase):
+    """Assert we can customise the notification to send a password reset."""
+    model = models.CustomVerifyEmailUser
+
+    def test_send_password_reset_email(self):
+        """Assert `text_email_template` and `html_template_name` can be customised."""
+        context = {}
+        site = Site.objects.get_current()
+        user = self.model(email='email@email.email')
+
+        with patch(PASSWORD_CONTEXT) as get_context:
+            get_context.return_value = context
+            with patch(SEND_METHOD) as send:
+                user.send_password_reset()
+
+        expected = {
+            'to': user.email,
+            'template_name': 'my_custom_email.txt',
+            'html_template_name': None,
+            'subject': '{} password reset'.format(site.domain),
+            'context': context,
+            'headers': {'test-header': 'Test'},
+        }
+        send.assert_called_once_with(**expected)
